import { apiLogout } from '@/components/Menu/api'
import { apiLogin } from '@/pages/Login/api'
import { iFromValues } from '@/types/login'
import { ProjectInfo } from '@/types/project'
import { iGroup, iUserInfo } from '@/types/setting'
import { apiGetGroupList, apiProjectInfo } from '@/utils/common/api'
import { delUserInfo, getUserInfo, saveUserInfo } from '@/utils/common/user'
import consts from '@/utils/consts'
import history from '@/utils/history'
import { action, computed, observable } from 'mobx'

class UserState {
  initUserState = {
    account: '',
    accountGroup: 0,
    company: '',
    csrf: '',
    enable: 0,
    id: '',
    isAdmin: 0,
    mobile: '',
    name: '',
    password: '',
    position: '',
    projectId: '',
    role: '',
    telephone: ''
  }
  @observable userInfo: iUserInfo = this.initUserState

  @observable permission: [] = []

  @observable showLeftSide: boolean = true

  @observable groupList:iGroup[] = []

  @observable projectInfo:ProjectInfo = { id: '', code: '', name: '',staffName: '', staffQq: '', staffPhone: '', staffTelephone: '' }

  @computed get isLogin() {
    return !!this.userInfo.id
  }
  @computed get role() {
    return this.userInfo.isAdmin ? 'ADMIN' : 'USER'
  }
  @computed get isAdmin() {
    return this.userInfo.isAdmin
  }

  @computed get projectName() {
    return this.projectInfo.name
  }

  @computed get menuBtnText() {
    return this.userInfo.name || this.userInfo.account
  }
  @action login(values: iFromValues) {
    apiLogin(values).then(({ code = -1, data }) => {
      if (code === consts.RET_CODE.SUCCESS) {
        saveUserInfo(data)
        this.userInfo = data
        history.push('/')
      }
    })
  }

  @action toggleLeftSide() {
    this.showLeftSide = !this.showLeftSide
  }

  @action async logout() {
    const { code = -1 } = await apiLogout()
    if (code === consts.RET_CODE.SUCCESS) {
      await delUserInfo()
      this.userInfo = this.initUserState
      history.push('/login')
    }
  }

  @action check() {
    const user: iUserInfo | null = getUserInfo()
    if (user) {
      this.userInfo = user
    }
  }

  @action getGroupList() {
    apiGetGroupList().then(({ code = -1, data = [] }) => {
      if (code === consts.RET_CODE.SUCCESS) {
        const newData = []
        for (const key in data) {
          if (Object.prototype.hasOwnProperty.call(data, key)) {
            const value: string = data[key]
            newData.push({ key: parseInt(key), value })
          }
        }
        this.groupList = newData
      }
    })
  }

  @action getProjectInfo() {
    apiProjectInfo().then(({ code = -1, data }) => {
      if (code === consts.RET_CODE.SUCCESS) {
        this.projectInfo = data
      }
    })
  }
}

export default new UserState()
